import setuptools

setuptools.setup(
    name="entityrender",
    version="0.2.0",
    author="Pedro Lima",
    author_email="pedro.lima@gmail.com",
    description="Basic entity span highlighting in text for visualization in notebooks",
    long_description_content_type="text/markdown",
    url="https://github.com/pvl/entityrender",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
